import{O as r}from"./workspaceStore.a9cf83e9.js";import{d as i,X as l,o as f,Y as u,b as d,w as a,u as n,aG as o,dd as c,dc as _}from"./index.abaf3ad4.js";import"./url.8ee60884.js";import"./colorHelpers.5d53a4e5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="def4d99e-fddb-4e8f-9ff3-2a73d465fe1d",e._sentryDebugIdIdentifier="sentry-dbid-def4d99e-fddb-4e8f-9ff3-2a73d465fe1d")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(f(),u("div",null,[d(n(c),null,{default:a(()=>[o("You're authenticated")]),_:1}),d(n(_),null,{default:a(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.e9d4951e.js.map
