import{C as n,A as t}from"./CollapsePanel.7bdb061c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3389cbc3-37b8-4ea6-8535-a92cb8002440",e._sentryDebugIdIdentifier="sentry-dbid-3389cbc3-37b8-4ea6-8535-a92cb8002440")}catch{}})();n.Panel=t;n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.a6a4f2c0.js.map
