import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.698e436d.js";import{L as i}from"./tasksController.4435e53d.js";import{d as p,o as d,c,w as a,b as o,aG as _,u as s,dd as f,a0 as m}from"./index.abaf3ad4.js";import{C as l}from"./ContentLayout.e5808468.js";import"./metadata.a596afae.js";import"./PhWebhooksLogo.vue.a1150008.js";import"./ant-design.adc06afb.js";import"./string.7a9e8232.js";import"./dayjs.d8312bc1.js";import"./index.12f607b2.js";import"./gateway.21d52798.js";import"./popupNotifcation.4879d617.js";import"./scripts.24ea2b00.js";import"./record.fee51533.js";import"./linters.0fabbf73.js";import"./asyncComputed.84aa5ffe.js";import"./polling.1abfd793.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1a308fe1-8e53-469f-9444-1e8322a2cd3f",e._sentryDebugIdIdentifier="sentry-dbid-1a308fe1-8e53-469f-9444-1e8322a2cd3f")}catch{}})();const u=p({__name:"Tasks",setup(e){const t=new i;return(r,y)=>(d(),c(l,null,{default:a(()=>[o(s(f),null,{default:a(()=>[_("Tasks")]),_:1}),o(n,{class:"tasks",api:s(t),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=m(u,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.bc9671ba.js.map
