import{d as t,o,Y as a,b as s,u as r,by as _,a0 as c}from"./index.abaf3ad4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="558d0846-5958-4dcd-a5ff-c22e3d046635",e._sentryDebugIdIdentifier="sentry-dbid-558d0846-5958-4dcd-a5ff-c22e3d046635")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,d)=>(o(),a("div",i,[s(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.e2c4170c.js.map
