import{d as i,o as p,c as n,w as a,b as m,u as t}from"./index.abaf3ad4.js";import"./linters.0fabbf73.js";import{W as s}from"./workspaces.16081016.js";import{C as d}from"./ContentLayout.e5808468.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.d188cbb5.js";import"./asyncComputed.84aa5ffe.js";import"./workspaceStore.a9cf83e9.js";import"./url.8ee60884.js";import"./colorHelpers.5d53a4e5.js";import"./record.fee51533.js";import"./gateway.21d52798.js";import"./popupNotifcation.4879d617.js";import"./fetch.9942dbc1.js";import"./SaveButton.03d64e2b.js";import"./UnsavedChangesHandler.85819ddf.js";import"./ExclamationCircleOutlined.193ac538.js";import"./CrudView.c10ee41e.js";import"./router.3b57fb6b.js";import"./Badge.05c5a8ba.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a65e24ff.js";import"./BookOutlined.2ea62891.js";import"./PhDotsThreeVertical.vue.b754dcc2.js";import"./index.12f607b2.js";import"./index.877779f4.js";import"./polling.1abfd793.js";import"./PhPencil.vue.10b5ae03.js";import"./index.7379e16a.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="c516dd95-1f21-4ab4-a4ce-870796dfa180",o._sentryDebugIdIdentifier="sentry-dbid-c516dd95-1f21-4ab4-a4ce-870796dfa180")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(d,null,{default:a(()=>[m(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.bcfdda0d.js.map
