import{L as t}from"./Logo.25cc61a3.js";import{d as n,o as r,c as a,u as d}from"./index.abaf3ad4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="01ec753b-699e-4949-8f35-8c8b9c9f2d61",e._sentryDebugIdIdentifier="sentry-dbid-01ec753b-699e-4949-8f35-8c8b9c9f2d61")}catch{}})();const i="/assets/logo.0faadfa2.svg",u=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(r(),a(t,{"image-url":d(i),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.01b40a66.js.map
