import{a0 as n,o,Y as d,$ as s,a,S as r}from"./index.abaf3ad4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d6c7228d-f030-48c8-a7ee-c56ed0c48e0c",e._sentryDebugIdIdentifier="sentry-dbid-d6c7228d-f030-48c8-a7ee-c56ed0c48e0c")}catch{}})();const c={},i={class:"base-layout"},f={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),d("div",i,[s(e.$slots,"sidebar",{},void 0,!0),a("section",f,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),d("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const b=n(c,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{b as B};
//# sourceMappingURL=BaseLayout.7ffcbde7.js.map
