import{U as s,dA as a,dB as i}from"./index.abaf3ad4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="127db0bc-6d58-47ce-b348-ec90fb0fd51b",e._sentryDebugIdIdentifier="sentry-dbid-127db0bc-6d58-47ce-b348-ec90fb0fd51b")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:b,TimePicker:f,QuarterPicker:c,RangePicker:o}=a(i),u=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:b,RangePicker:o,TimePicker:f,QuarterPicker:c,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(c.name,c),e)});export{u as D,r as M,c as Q,o as R,t as W};
//# sourceMappingURL=dayjs.d8312bc1.js.map
