import"./index.abaf3ad4.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="f537f955-f63c-467e-9b3a-a899ebb04ef1",x._sentryDebugIdIdentifier="sentry-dbid-f537f955-f63c-467e-9b3a-a899ebb04ef1")}catch{}})();const f=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{f as u};
//# sourceMappingURL=uuid.ecc0e70e.js.map
