import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.d188cbb5.js";import{d as i,ea as s,o as m,c as d,u as a}from"./index.abaf3ad4.js";import"./gateway.21d52798.js";import"./popupNotifcation.4879d617.js";import"./fetch.9942dbc1.js";import"./record.fee51533.js";import"./SaveButton.03d64e2b.js";import"./UnsavedChangesHandler.85819ddf.js";import"./ExclamationCircleOutlined.193ac538.js";import"./CrudView.c10ee41e.js";import"./router.3b57fb6b.js";import"./Badge.05c5a8ba.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a65e24ff.js";import"./BookOutlined.2ea62891.js";import"./url.8ee60884.js";import"./PhDotsThreeVertical.vue.b754dcc2.js";import"./index.12f607b2.js";import"./index.877779f4.js";import"./asyncComputed.84aa5ffe.js";import"./polling.1abfd793.js";import"./PhPencil.vue.10b5ae03.js";import"./index.7379e16a.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="99c940fd-394f-4c32-a3d7-9911dbdb94f2",o._sentryDebugIdIdentifier="sentry-dbid-99c940fd-394f-4c32-a3d7-9911dbdb94f2")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(c,f)=>(m(),d(n,{"env-var-repository":a(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.9c89f509.js.map
