import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.1952a04e.js";import{d as m,eo as f,ea as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.abaf3ad4.js";import{u as h}from"./workspaceStore.a9cf83e9.js";import"./Logo.25cc61a3.js";import"./string.7a9e8232.js";import"./CircularLoading.8c2baea2.js";import"./index.72c98ac7.js";import"./index.7379e16a.js";import"./url.8ee60884.js";import"./colorHelpers.5d53a4e5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d53633b8-f4d9-4bcc-ab9b-edbdda7b2773",e._sentryDebugIdIdentifier="sentry-dbid-d53633b8-f4d9-4bcc-ab9b-edbdda7b2773")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=b(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var d,c,p,u,i;return g(),y("div",v,[w(l,{"logo-url":(c=(d=n(r).state.workspace)==null?void 0:d.logoUrl)!=null?c:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-ce854d6f"]]);export{H as default};
//# sourceMappingURL=Login.e33f7611.js.map
