import{k as n,T as a,m as r,P as o,C as d,M as p,s as c,n as s,p as b,q as f,t as m,v as u}from"./index.abaf3ad4.js";import{s as g,c as y,a as i}from"./workspaceStore.a9cf83e9.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.8a230d3c.js";import"./url.8ee60884.js";import"./colorHelpers.5d53a4e5.js";import"./PlayerConfigProvider.e4b43e61.js";import"./index.72c98ac7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="be9b0b6b-dde4-410f-8465-b9025eb0c5cf",t._sentryDebugIdIdentifier="sentry-dbid-be9b0b6b-dde4-410f-8465-b9025eb0c5cf")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await g();const t=y(),e=n({render:()=>b(l)});a.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,f),s(e,m),s(e,u)})();
//# sourceMappingURL=player.0443786e.js.map
