import{P as m}from"./PlayerNavbar.bfbcfbbd.js";import{d as g,eo as h,ea as c,e as y,f as b,r as k,o as i,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.abaf3ad4.js";import{u as V}from"./workspaceStore.a9cf83e9.js";import"./metadata.a596afae.js";import"./PhWebhooksLogo.vue.a1150008.js";import"./LoadingOutlined.eb13bd9d.js";import"./PhSignOut.vue.42a44544.js";import"./index.d045fd91.js";import"./Avatar.26fee0bf.js";import"./url.8ee60884.js";import"./colorHelpers.5d53a4e5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="37993622-697a-4ff6-b735-3171bfca8fe2",o._sentryDebugIdIdentifier="sentry-dbid-37993622-697a-4ff6-b735-3171bfca8fe2")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,a=y(null),d=async({path:s,id:r})=>{a.value=r,await e.push({path:`/${s}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(s,r)=>{const f=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(m,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(f)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.bb83e6c4.js.map
