import{d as l,eh as c,f as r,o,Y as t,S as d,e9 as f,a0 as _}from"./index.abaf3ad4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9e548fa1-ad90-4d09-9bca-199dfeff4232",e._sentryDebugIdIdentifier="sentry-dbid-9e548fa1-ad90-4d09-9bca-199dfeff4232")}catch{}})();const p={class:"logo"},u=["src","alt"],g={key:1},m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const a=e;c(s=>({"9303a762":n.value}));const n=r(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),i=r(()=>`${a.brandName} Logo`);return(s,y)=>(o(),t("div",p,[s.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:i.value},null,8,u)):d("",!0),s.hideText?d("",!0):(o(),t("span",g,f(s.brandName),1))]))}});const h=_(m,[["__scopeId","data-v-f2a3ae27"]]);export{h as L};
//# sourceMappingURL=Logo.25cc61a3.js.map
