import{d as i,eo as m,ea as p,o as l,c as f,w as u,u as n,Y as _,eb as g,b as y,a as v,e9 as w,aS as k}from"./index.abaf3ad4.js";import{A as I,T}from"./TabPane.fc901a4e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="756bbf6d-aa90-41a3-8e99-ae4b153b6aa8",e._sentryDebugIdIdentifier="sentry-dbid-756bbf6d-aa90-41a3-8e99-ae4b153b6aa8")}catch{}})();const B=i({__name:"TablesTabs",setup(e){const a=m(),t=p(),b=String(t.name),c=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],d=o=>{a.push({name:String(o),params:{projectId:c}})};return(o,D)=>(l(),f(n(T),{"active-key":n(b),options:r,"onUpdate:activeKey":d},{default:u(()=>[(l(),_(k,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:u(()=>[v("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{B as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.469ca5cf.js.map
