import{d as n,o as d,Y as s,a,$ as r,ed as l,a0 as _}from"./index.abaf3ad4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4b2bcd91-1f22-4da9-8ed7-47119b20f362",e._sentryDebugIdIdentifier="sentry-dbid-4b2bcd91-1f22-4da9-8ed7-47119b20f362")}catch{}})();const c={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(d(),s("div",c,[a("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=_(u,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.e5808468.js.map
