import{cM as n}from"./index.abaf3ad4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="dfd14dc4-120b-4745-b551-344c519a4202",e._sentryDebugIdIdentifier="sentry-dbid-dfd14dc4-120b-4745-b551-344c519a4202")}catch{}})();const t=(e,d,r)=>{n.error({message:e,description:d,onClick:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.4879d617.js.map
